"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var forms_1 = require("@angular/forms");
var router_1 = require("@angular/router");
var object_service_1 = require("../../utilities/object.service");
exports.UNDEFINED_NAME = 'SearchFormComponent_name_unspecified';
exports.DEFAULT_TARGET = './search';
var SearchFormComponent = (function () {
    function SearchFormComponent(formBuilder, router, objectService) {
        this.formBuilder = formBuilder;
        this.router = router;
        this.objectService = objectService;
        this.configuredOptions = {
            name: exports.UNDEFINED_NAME,
            target: exports.DEFAULT_TARGET
        };
        this.searchForm = this.formBuilder.group({
            terms: [this.terms, forms_1.Validators.required]
        });
        this.searchedTerms = new core_1.EventEmitter();
    }
    SearchFormComponent.prototype.ngOnInit = function () {
        if (!!this.options) {
            this.configuredOptions = this.objectService.shallowCopy(this.configuredOptions, this.options);
        }
    };
    SearchFormComponent.prototype.search = function () {
        if (!this.searchForm.valid) {
            return;
        }
        this.searchedTerms.emit(this.terms);
        this.router.navigate([this.configuredOptions.target], { queryParams: { q: this.terms } });
    };
    return SearchFormComponent;
}());
SearchFormComponent.decorators = [
    { type: core_1.Component, args: [{
                selector: 'app-search-form',
                template: "<div class=\"row\"> <form [formGroup]=\"searchForm\" (ngSubmit)=\"search()\"> <div class=\"col-md-10\"> <input formControlName=\"terms\" [(ngModel)]=\"terms\" type=\"text\" placeholder=\"Separate search terms by ,\" /> </div> <div class=\"col-md-2\"> <button type=\"submit\">Search</button> </div> </form> </div> ",
                styles: [""]
            },] },
];
/** @nocollapse */
SearchFormComponent.ctorParameters = function () { return [
    { type: forms_1.FormBuilder, },
    { type: router_1.Router, },
    { type: object_service_1.ObjectService, },
]; };
SearchFormComponent.propDecorators = {
    'options': [{ type: core_1.Input },],
    'searchedTerms': [{ type: core_1.Output },],
};
exports.SearchFormComponent = SearchFormComponent;
//# sourceMappingURL=search-form.component.js.map